=============================
PySimple
=============================

.. image:: https://badge.fury.io/py/pysimple.png
    :target: http://badge.fury.io/py/pysimple

.. image:: https://travis-ci.org/TFenby/PySimple.svg?branch=master
    :target: https://travis-ci.org/TFenby/pysimple

.. image:: https://pypip.in/status/pysimple/badge.svg
    :target: https://pypi.python.org/pypi/pysimple


A client library and reference implementation for Simple's online banking site.

* Free software: GPLv3
* Documentation: https://pysimple.readthedocs.org

Features
--------

* Basic account balance and goal support
